@@ -13,14 +13,14 @@
 ##############################################################################
 from zope.viewlet.viewlet import JavaScriptViewlet
 
-YahooBase = JavaScriptViewlet('yui/yahoo/yahoo.js')
-YahooEvent = JavaScriptViewlet('yui/event/event.js')
-YahooConnection = JavaScriptViewlet('yui/connection/connection.js')
-YahooDom = JavaScriptViewlet('yui/dom/dom.js')
+YahooBase = JavaScriptViewlet('yui/build/yahoo/yahoo.js')
+YahooEvent = JavaScriptViewlet('yui/build/event/event.js')
+YahooConnection = JavaScriptViewlet('yui/build/connection/connection.js')
+YahooDom = JavaScriptViewlet('yui/build/dom/dom.js')
 YahooCore = JavaScriptViewlet('yui/build/yahoo-dom-event/yahoo-dom-event.js')
-YahooLogger = JavaScriptViewlet('yui/logger/logger-min.js')
-YahooElement = JavaScriptViewlet('yui/element/element-beta.js')
-YahooDataSource = JavaScriptViewlet('yui/datasource/datasource-beta.js')
-YahooDataTable = JavaScriptViewlet('yui/datatable/datatable-beta.js')
-YahooTree = JavaScriptViewlet('yui/treeview/treeview.js')
-YahooSelector = JavaScriptViewlet('yui/selector/selector.js')
+YahooLogger = JavaScriptViewlet('yui/build/logger/logger-min.js')
+YahooElement = JavaScriptViewlet('yui/build/element/element-beta.js')
+YahooDataSource = JavaScriptViewlet('yui/build/datasource/datasource-beta.js')
+YahooDataTable = JavaScriptViewlet('yui/build/datatable/datatable-beta.js')
+YahooTree = JavaScriptViewlet('yui/build/treeview/treeview.js')
+YahooSelector = JavaScriptViewlet('yui/build/selector/selector.js')
